@@ -7,11 +7,11 @@ from typing import Any
 
 _CONNECTION_DEFAULT_TIMEOUT = 5.0
 _READ_DEFAULT_TIMEOUT = 5.0
-_READ_DEFAULT_BUFFER_SIZE = 512  # 512 bytes
-_QUEUE_DEFAULT_WAIT_TIMEOUT = 1.0
-_RECEIVE_DEFAULT_INTERVAL = 0.3
-_SEND_DEFAULT_INTERVAL = 0.4
-_SEND_DEFAULT_RETRY_COUNT = 5
+_READ_BUFFER_DEFAULT_SIZE = 512  # 512 bytes
+_QUEUE_WAIT_DEFAULT_TIMEOUT = 1.0
+_RECEIVE_PACKET_DEFAULT_INTERVAL = 0.3
+_SEND_PACKET_DEFAULT_INTERVAL = 0.4
+_SEND_PACKET_RETRY_DEFAULT_COUNT = 5
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -39,9 +39,6 @@ class _WpSendData:
 
     async def wait(self) -> bool:
         """Socket send wait"""
-        if self._complete.is_set():
-            self._complete.clear()
-
         await self._complete.wait()
         return self._result
 
@@ -53,9 +50,9 @@ class WpSocketConfig:
     read_timeout: float
     read_buffer_size: int
     queue_wait_timeout: float
-    receive_interval: float
-    send_interval: float
-    send_retry_count: int
+    receive_packet_interval: float
+    send_packet_interval: float
+    send_packet_retry_count: int
 
 
 class WpSocketClient:
@@ -68,13 +65,13 @@ class WpSocketClient:
         self.port = port
         self._async_receive_handler = async_packets_handler
         self._config = WpSocketConfig(
-            kwds.pop('connection_timout', _CONNECTION_DEFAULT_TIMEOUT),
+            kwds.pop('connection_timeout', _CONNECTION_DEFAULT_TIMEOUT),
             kwds.pop('read_timeout', _READ_DEFAULT_TIMEOUT),
-            kwds.pop('read_buffer_size', _READ_DEFAULT_BUFFER_SIZE),
-            kwds.pop('queue_wait_timeout', _QUEUE_DEFAULT_WAIT_TIMEOUT),
-            kwds.pop('receive_interval', _RECEIVE_DEFAULT_INTERVAL),
-            kwds.pop('send_interval', _SEND_DEFAULT_INTERVAL),
-            kwds.pop('send_retry_count', _SEND_DEFAULT_RETRY_COUNT)
+            kwds.pop('read_buffer_size', _READ_BUFFER_DEFAULT_SIZE),
+            kwds.pop('queue_wait_timeout', _QUEUE_WAIT_DEFAULT_TIMEOUT),
+            kwds.pop('receive_packet_interval', _RECEIVE_PACKET_DEFAULT_INTERVAL),
+            kwds.pop('send_packet_interval', _SEND_PACKET_DEFAULT_INTERVAL),
+            kwds.pop('send_packet_retry_count', _SEND_PACKET_RETRY_DEFAULT_COUNT)
         )
 
         self._wait_tasks: Any = None
@@ -184,8 +181,8 @@ class WpSocketClient:
                     now = time.time()
                     send_interval = now - self._last_send_time
                     receive_interval = now - self._last_receive_time
-                    if send_interval > self._config.receive_interval \
-                            and receive_interval > self._config.send_interval:
+                    if send_interval > self._config.receive_packet_interval \
+                            and receive_interval > self._config.send_packet_interval:
                         self._writer.write(send_data.packet)
                         await self._writer.drain()
                         self._last_send_time = time.time()
@@ -194,17 +191,17 @@ class WpSocketClient:
                         self._send_packet_queue.task_done()
                         break
 
-                    if send_data.inc_try() > self._config.send_retry_count:
+                    if send_data.inc_try() > self._config.send_packet_retry_count:
                         send_data.set(False)
                         _LOGGER.warning('Send fail: %s', send_data.packet.hex())
                         break
 
                     if send_interval > receive_interval:
-                        delay = self._config.receive_interval - receive_interval
+                        delay = self._config.receive_packet_interval - receive_interval
                         _LOGGER.info('Send, wait receive interval : %f', delay)
                         await asyncio.sleep(delay)
                     else:
-                        delay = self._config.send_interval - send_interval
+                        delay = self._config.send_packet_interval - send_interval
                         _LOGGER.info('Send, wait send interval: %f', delay)
                         await asyncio.sleep(delay)
 
